@@ -51,15 +51,16 @@
     # Variance gamma (symmetric and asymmetric)
       eps <- .Machine$double.eps
       # Observations that are close to mu were kept at a minimum magnitude
-      if(any(abs(Q)<eps)){
+      if(any(Q < eps)){
         # If lambda == 0.5 * dimension, there is another singularity.
         if(abs(lambda-0.5*d)<eps){
-          stop("Unhandled singularity: Some observations are close to 0 (< ",eps
-          , ") and lambda is close to 0.5 * dimension!\n")
+          stop("Unhandled singularity: Some standardized observations are close to 0 (< ",
+               eps, ") and lambda is close to 0.5 * dimension!\n")
         }else{
-          Q[abs(Q)<eps] <- sign(Q[abs(Q)<eps])* eps
+          Q[Q < eps] <- eps
           Q[Q==0] <- eps
-          warning("Some observations are close to 0 (< ",eps,")!\n", immediate. = TRUE)
+          warning("Singularity: Some standardized observations are close to 0 (< ",eps,")!\n", 
+                  "Observations set to ",eps,".\n",immediate. = TRUE)
         }
       }
       log.top <-
